import { useCallback, useEffect, useState } from "react"
import type { Vault, OnePassword } from "opvault.js"
import { useIdleTimer } from "react-idle-timer/modern"
import { VaultView } from "./pages/Vault"
import { VaultPicker } from "./pages/VaultPicker"

export const App: React.FC = () => {
  const [instance, setInstance] = useState<OnePassword>()
  const [vault, setVault] = useState<Vault>()

  const onLock = useCallback(() => {
    vault?.lock()
    setVault(undefined)
  }, [vault])

  const { reset, pause } = useIdleTimer({
    timeout: 60_000,
    onIdle: onLock,
  })

  useEffect(() => {
    if (vault) {
      reset()
    } else {
      pause()
    }
  }, [vault])

  if (!vault) {
    return (
      <VaultPicker
        instance={instance}
        setInstance={setInstance}
        vault={vault}
        setVault={setVault}
      />
    )
  }

  return (
    <div>
      <VaultView onLock={onLock} vault={vault} />
    </div>
  )
}
