import styled from "@emotion/styled"
import { useCallback, useEffect, useState } from "react"
import type { Vault } from "opvault.js"
import { OnePassword } from "opvault.js"
import { Unlock } from "./Unlock"
import { electronAdapter, openDirectory } from "../utils/ipc-adapter"
import { get, remove, set, Key } from "../utils/localStorage"
import { useTranslate } from "../i18n"

interface VaultPickerProps {
  instance: OnePassword | undefined
  setInstance(value?: OnePassword): void
  vault: Vault | undefined
  setVault(vault?: Vault): void
}

export const VaultPicker: React.FC<VaultPickerProps> = ({
  instance,
  setInstance,
  vault,
  setVault,
}) => {
  const [vaultPath, setVaultPath] = useState("")

  const unlock = useCallback(
    async (profile: string, password: string) => {
      const vault = await instance!.getProfile(profile!)
      await vault.unlock(password)
      setVault(vault)
    },
    [instance]
  )

  const clearInstance = useCallback(() => {
    setVaultPath("")
    setInstance(undefined)
  }, [])

  useEffect(() => {
    const existingPath = get(Key.LAST_VAULT_PATH)
    if (existingPath != null) {
      setVaultPath(existingPath)
    }
  }, [])

  useEffect(() => {
    if (vaultPath) {
      const instance = new OnePassword({
        path: vaultPath,
        adapter: electronAdapter,
      })
      setInstance(instance)
      set(Key.LAST_VAULT_PATH, vaultPath)
    } else {
      setInstance(undefined)
      remove(Key.LAST_VAULT_PATH)
    }
  }, [vaultPath])

  if (!instance) {
    return <PickOPVault setPath={setVaultPath} />
  }
  if (!vault) {
    return <Unlock onReturn={clearInstance} instance={instance} onUnlock={unlock} />
  }
  return null
}

const PickOPVaultContainer = styled.div`
  padding: 100px;
  text-align: center;
`
const PickOPVaultInfo = styled.div`
  margin: 10px;
`
const PickOPVault: React.FC<{
  setPath(path: string): void
}> = ({ setPath }) => {
  const t = useTranslate()

  const onClick = useCallback(async () => {
    const path = await openDirectory()
    if (path) {
      setPath(path)
    }
  }, [setPath])

  return (
    <PickOPVaultContainer>
      <button onClick={onClick}>{t.label.choose_a_vault}</button>
      <PickOPVaultInfo>{t.label.no_vault_selected}</PickOPVaultInfo>
    </PickOPVaultContainer>
  )
}
